@@ -11,7 +11,7 @@ use warnings;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use Path::Class;
+use Path::Tiny;
 use W3C::SOAP::Utils qw/ns2module/;
 use W3C::SOAP::XSD::Parser;
 use W3C::SOAP::WSDL::Document;
@@ -24,7 +24,7 @@ Moose::Exporter->setup_import_methods(
 
 extends 'W3C::SOAP::Parser';
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 has '+document' => (
     isa      => 'W3C::SOAP::WSDL::Document',
@@ -58,7 +58,7 @@ sub write_modules {
     my $template = $self->template;
     my $file     = $self->lib . '/' . $self->module . '.pm';
     $file =~ s{::}{/}g;
-    $file = file $file;
+    $file = path($file);
     my $parent = $file->parent;
     my @missing;
     while ( !-d $parent ) {
@@ -220,7 +220,7 @@ libraries to access the Web Service defined.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Parser version 0.12.
+This documentation refers to W3C::SOAP::WSDL::Parser version 0.13.
 
 =head1 SYNOPSIS
 
