@@ -14,7 +14,7 @@ use List::Util;
 #use List::MoreUtils;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use Path::Class;
+use Path::Tiny;
 use XML::LibXML;
 use WWW::Mechanize;
 use Try::Tiny;
@@ -27,7 +27,7 @@ use W3C::SOAP::Utils qw/normalise_ns ns2module/;
 
 extends 'W3C::SOAP::Document';
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 has element_form_default => (
     is         => 'rw',
@@ -152,7 +152,7 @@ sub _imports {
             ) {
                 my $current_location
                     = -f $self->location
-                    ? file($self->location)->absolute . ''
+                    ? path($self->location)->absolute . ''
                     : $self->location;
 
                 $location = URI->new_abs($location, $current_location)->as_string;
@@ -417,7 +417,7 @@ W3C::SOAP::XSD::Document - Represents a XMLSchema Document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document version 0.12.
+This documentation refers to W3C::SOAP::XSD::Document version 0.13.
 
 =head1 SYNOPSIS
 
