@@ -14,7 +14,7 @@ use List::Util;
 use List::MoreUtils qw/all/;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use Path::Class;
+use Path::Tiny;
 use W3C::SOAP::XSD::Document;
 use File::ShareDir qw/dist_dir/;
 use Moose::Util::TypeConstraints;
@@ -27,7 +27,7 @@ Moose::Exporter->setup_import_methods(
 
 extends 'W3C::SOAP::Parser';
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 subtype xsd_documents =>
     as 'ArrayRef[W3C::SOAP::XSD::Document]';
@@ -63,7 +63,7 @@ sub write_modules {
         $self_module ||= $module;
         my $file   = $self->lib . '/' . $module;
         $file =~ s{::}{/}gxms;
-        $file = file $file;
+        $file = path($file);
         my $parent = $file->parent;
         my @missing;
         while ( !-d $parent ) {
@@ -89,7 +89,7 @@ sub write_modules {
             push @parents, $type_module;
             my $type_file = $self->lib . '/' . $type_module;
             $type_file =~ s{::}{/}gxms;
-            $type_file = file $type_file;
+            $type_file = path($type_file);
             mkdir $type_file->parent if !-d $type_file->parent;
 
             my %modules;
@@ -443,7 +443,7 @@ implementing the object defined.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Parser version 0.12.
+This documentation refers to W3C::SOAP::XSD::Parser version 0.13.
 
 =head1 SYNOPSIS
 
